#
# spec file for package hatari
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:         hatari
Version:      1.9.0
Release:      1.107
Summary:      An Atari ST emulator suitable for playing games
License:      GPL-2.0
Group:        System/Emulators/Other
Url:          http://hatari.tuxfamily.org/
Source:       http://download.tuxfamily.org/%{name}/%{version}/%{name}-%{version}.tar.bz2
BuildRequires: cmake
BuildRequires: readline-devel
BuildRequires: portaudio-devel
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(python) >= 2.7
BuildRequires: pkgconfig(pygtk-2.0)
BuildRequires: pkgconfig(sdl2)
BuildRequires: desktop-file-utils
Requires: hicolor-icon-theme
# Required by zip2st and atari-hd-image
Requires: unzip
Requires: mtools
Requires: dosfstools
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

%description
This is an emulator for the Atari ST, STE, TT and Falcon computers.
The Atari ST was a 16/32 bit computer system which was first released by Atari
in 1985. Using the Motorola 68000 CPU, it was a very popular computer having
quite a lot of CPU power at that time.
Unlike many other Atari ST emulators which try to give you a good environment
for running GEM applications, Hatari tries to emulate the hardware of a ST as
close as possible so that it is able to run most of the old ST games and demos.

%prep
%setup -q

# Remove shebang from non executable scripts
for pyfile in dialogs.py hatari.py uihelpers.py config.py
do
  sed -i -e '/^#!\//, 1d' python-ui/$pyfile
done

# Fix desktop file
sed -i '/^MimeType=*/s/$/;/' \
  share/applications/%{name}.desktop

%build
cmake \
  -DCMAKE_INSTALL_PREFIX=/usr \
  -DENABLE_DSP_EMU=1 \
  -DENABLE_SDL2=1 \
  -DENABLE_WINUAE_CPU=1 \
  -DDOCDIR=%{_docdir}/%{name} .

make %{?_smp_mflags}

%install
%make_install

# Fix file permissions
chmod 644 %{buildroot}%{_datadir}/%{name}/hatariui/conftypes.py

# Install French man page
install -d -m 755 %{buildroot}%{_mandir}/fr/man1
install -p -m 644 doc/fr/hatari.1 %{buildroot}%{_mandir}/fr/man1

# Install hatari desktop file
desktop-file-install \
  --delete-original \
  --remove-key Encoding \
  --set-comment="Atari ST/STE/TT/Falcon emulator" \
  --remove-category Game \
  --add-category System \
  --add-category Emulator \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/hatari.desktop

# Install hatari-ui desktop file
desktop-file-install \
  --delete-original \
  --remove-key Encoding \
  --set-comment="External user interface for Hatari" \
  --copy-name-to-generic-name \
  --add-category System \
  --add-category Emulator \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/hatariui.desktop

%files
%defattr(-,root,root)
%{_bindir}/*
%{_datadir}/%{name}
%{_mandir}/man1/*
%{_mandir}/fr/man1/*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/*/mimetypes/application-x-st-disk-image.*
%{_datadir}/mime/packages/hatari.xml
%{_datadir}/applications/*
%{_docdir}/%{name}

%changelog
* Thu Apr  7 2016 kieltux@gmail.com
- Update to 1.9.0
- Rewrite of spec file
* Thu Mar 20 2008 uli@suse.de
- update -> 1.0.0
* Sun May  6 2007 thothy@users.sourceforge.net
- Adapted spec file to be able to build Hatari with RedHat, too
* Sun Aug 27 2006 thothy@users.sourceforge.net
- Upgraded to version 0.90
* Tue Oct 18 2005 thothy@users.sourceforge.net
- initial package
